@@ -15,8 +15,8 @@ describe 'panko::keystone::authtoken' do
         is_expected.to contain_panko_config('keystone_authtoken/password').with_value('secrete')
         is_expected.to contain_panko_config('keystone_authtoken/auth_url').with_value('http://localhost:35357')
         is_expected.to contain_panko_config('keystone_authtoken/project_name').with_value('services')
-        is_expected.to contain_panko_config('keystone_authtoken/user_domain_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_panko_config('keystone_authtoken/project_domain_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_panko_config('keystone_authtoken/user_domain_name').with_value('Default')
+        is_expected.to contain_panko_config('keystone_authtoken/project_domain_name').with_value('Default')
         is_expected.to contain_panko_config('keystone_authtoken/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_panko_config('keystone_authtoken/auth_section').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_panko_config('keystone_authtoken/auth_type').with_value('password')
